@@ -4,7 +4,7 @@
 <context>
     <name>QObject</name>
     <message>
-        <location filename="../src/core/RUnit.cpp" line="+273"/>
+        <location filename="../src/core/RUnit.cpp" line="+272"/>
         <source>None</source>
         <translation type="unfinished">Κανένα</translation>
     </message>
@@ -238,10 +238,10 @@
 <context>
     <name>REntity</name>
     <message>
-        <location filename="../src/core/RBlock.cpp" line="+63"/>
-        <location filename="../src/core/RLayer.cpp" line="+93"/>
+        <location filename="../src/core/RBlock.cpp" line="+67"/>
+        <location filename="../src/core/RLayer.cpp" line="+95"/>
         <location filename="../src/core/RLayerState.cpp" line="+46"/>
-        <location filename="../src/core/RLayout.cpp" line="+82"/>
+        <location filename="../src/core/RLayout.cpp" line="+81"/>
         <source>Name</source>
         <translation type="unfinished">Όνομα</translation>
     </message>
@@ -264,7 +264,7 @@
     </message>
     <message>
         <location line="-2"/>
-        <location filename="../src/core/RBlockReferenceEntity.cpp" line="+95"/>
+        <location filename="../src/core/RBlockReferenceEntity.cpp" line="+99"/>
         <location line="+3"/>
         <location filename="../src/core/RLayout.cpp" line="+2"/>
         <location line="+3"/>
@@ -272,7 +272,7 @@
         <location line="+3"/>
         <location line="+3"/>
         <location filename="../src/core/RTextBasedEntity.cpp" line="+75"/>
-        <location filename="../src/core/RViewportEntity.cpp" line="+73"/>
+        <location filename="../src/core/RViewportEntity.cpp" line="+80"/>
         <location line="+8"/>
         <location line="+2"/>
         <source>X</source>
@@ -315,7 +315,12 @@
         <translation type="unfinished">Διάταξη</translation>
     </message>
     <message>
-        <location filename="../src/core/RBlockReferenceData.cpp" line="+856"/>
+        <location line="+1"/>
+        <source>Owned by Reference</source>
+        <translation type="unfinished">Κατέχεται από Αναφορά</translation>
+    </message>
+    <message>
+        <location filename="../src/core/RBlockReferenceData.cpp" line="+886"/>
         <source>Circular (recursive) block referencing detected:</source>
         <translation type="unfinished">Εντοπίστηκε κυκλική (αναδρομική) αναφορά σε μπλοκ:</translation>
     </message>
@@ -498,8 +503,8 @@
         <translation type="unfinished">Μπλοκ βέλους 2</translation>
     </message>
     <message>
-        <location filename="../src/core/REntity.cpp" line="+96"/>
-        <location filename="../src/core/RObject.cpp" line="+69"/>
+        <location filename="../src/core/REntity.cpp" line="+94"/>
+        <location filename="../src/core/RObject.cpp" line="+70"/>
         <source>Type</source>
         <translation type="unfinished">Τύπος</translation>
     </message>
@@ -680,7 +685,7 @@
     </message>
     <message>
         <location filename="../src/core/RObject.cpp" line="-1"/>
-        <location filename="../src/core/RPropertyTypeId.cpp" line="+161"/>
+        <location filename="../src/core/RPropertyTypeId.cpp" line="+162"/>
         <source>Custom</source>
         <translation type="unfinished">Προσαρμοσμένο</translation>
     </message>
@@ -825,11 +830,21 @@
         <source>Overall</source>
         <translation type="unfinished">Συνολικά</translation>
     </message>
+    <message>
+        <location line="+2"/>
+        <source>Frozen Layers</source>
+        <translation type="unfinished">Κατεψυγμένα στρώματα</translation>
+    </message>
+    <message>
+        <location line="+0"/>
+        <source>Layer ID</source>
+        <translation type="unfinished">Αναγνωριστικό στρώματος</translation>
+    </message>
 </context>
 <context>
     <name>RGuiAction</name>
     <message>
-        <location filename="../src/core/RGuiAction.cpp" line="+202"/>
+        <location filename="../src/core/RGuiAction.cpp" line="+203"/>
         <source>Requires selection</source>
         <translation type="unfinished">Απαιτεί επιλογή</translation>
     </message>
@@ -837,7 +852,7 @@
 <context>
     <name>RLinetype</name>
     <message>
-        <location filename="../src/core/RLinetype.cpp" line="+54"/>
+        <location filename="../src/core/RLinetype.cpp" line="+51"/>
         <source>Name</source>
         <translation type="unfinished">Όνομα</translation>
     </message>
@@ -1043,7 +1058,7 @@
     <message>
         <location line="+2"/>
         <source>Water</source>
-        <translation type="unfinished"></translation>
+        <translation type="unfinished">Νερό</translation>
     </message>
     <message>
         <location line="+1"/>
@@ -1058,43 +1073,43 @@
     <message>
         <location line="+2"/>
         <source>Communication</source>
-        <translation type="unfinished"></translation>
+        <translation type="unfinished">Επικοινωνία</translation>
     </message>
     <message>
         <location line="+1"/>
         <source>Electric</source>
-        <translation type="unfinished"></translation>
+        <translation type="unfinished">Ηλεκτρικό</translation>
     </message>
     <message>
         <location line="+1"/>
         <source>Low Voltage</source>
-        <translation type="unfinished"></translation>
+        <translation type="unfinished">Χαμηλή τάση</translation>
     </message>
     <message>
         <location line="+1"/>
         <source>High Voltage</source>
-        <translation type="unfinished"></translation>
+        <translation type="unfinished">Υψηλή τάση</translation>
     </message>
     <message>
         <location line="+1"/>
         <source>Overhead Power</source>
-        <translation type="unfinished"></translation>
+        <translation type="unfinished">Εναέρια ισχύς</translation>
     </message>
     <message>
         <location line="+2"/>
         <source>Foul</source>
-        <translation type="unfinished"></translation>
+        <translation type="unfinished">Foul</translation>
     </message>
     <message>
         <location line="+1"/>
         <source>Foul Rising</source>
-        <translation type="unfinished"></translation>
+        <translation type="unfinished">Foul Rising</translation>
     </message>
 </context>
 <context>
     <name>RLineweight</name>
     <message>
-        <location filename="../src/core/RLineweight.cpp" line="+35"/>
+        <location filename="../src/core/RLineweight.cpp" line="+37"/>
         <source>By Layer</source>
         <translation type="unfinished">Με στρώμα</translation>
     </message>
@@ -1230,3 +1245,4 @@
     </message>
 </context>
 </TS>
+
